![HorizonGRound](./docs/source/_static/HorizonGRound.png)

[![pypi](https://img.shields.io/badge/version-0.1-informational)](
https://pypi.org/project/HorizonGRound/)
[![licence](https://img.shields.io/badge/licence-GPLv3-informational)](
https://github.com/mikeswang/HorizonGRound/tree/v0.1.0/LICENCE)
[![GitHub](https://img.shields.io/badge/GitHub-MikeSWang%2FHorizonGRound-informational
)](https://github.com/mikeswang/HorizonGRound/tree/v0.1.0)
[![arXiv](https://img.shields.io/badge/arXiv-2007.xxxxx-important
)](https://arxiv.org/abs/2007.xxxxx)


# Relativistic Effects in Ultra-Large-Scale Clustering

<span style="font-variant: small-caps">HorizonGRound</span> is a Python
package that offers tools for forward modelling of general relativistic
effects from tracer luminosity functions as well as comparing relativistic
corrections with the local primordial non-Gaussianity signature in
ultra-large-scale clustering statistics.


## Installation

The simplest installation method is ``pip``:

```bash
pip install HorizonGRound
```


## Documentation

API documentation and quick recipes can be found at
[mikeswang.github.io/HorizonGRound](
https://mikeswang.github.io/HorizonGRound/).


## Attribution

If you would like to acknowledge this work please consider citing
`Wang, Beutler & Bacon (2020) <https://arxiv.org/abs/2007.xxxxx>`_. You
may use the following BibTeX record.

    @article{Wang_2020,
        author = {Wang, M.~S. and Beutler, F. and Bacon, D.},
        title = {%
            Impact of relativistic effects on the primordial {non-Gaussianity} %
            signature in the large-scale clustering of quasars%
        },
        year = {2020},
        archivePrefix = {arXiv},
        primaryClass = {astro-ph.CO}
        eprint = {2007.xxxx},
    }


## Licence

Copyright 2020, M S Wang

<span style="font-variant: small-caps">HorizonGRound</span> is made freely
available under the [GPL v3.0](https://www.gnu.org/licenses/gpl-3.0.en.html)
licence.
